@@ -32,6 +32,7 @@ import (
 	"github.com/openshift/cluster-etcd-operator/pkg/operator/configobservation/configobservercontroller"
 	"github.com/openshift/cluster-etcd-operator/pkg/operator/etcd_assets"
 	"github.com/openshift/cluster-etcd-operator/pkg/operator/etcdcertsigner"
+	"github.com/openshift/cluster-etcd-operator/pkg/operator/etcdendpointscontroller"
 	"github.com/openshift/cluster-etcd-operator/pkg/operator/etcdmemberipmigrator"
 	"github.com/openshift/cluster-etcd-operator/pkg/operator/etcdmemberscontroller"
 	"github.com/openshift/cluster-etcd-operator/pkg/operator/hostendpointscontroller2"
@@ -181,7 +182,6 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 	etcdCertSignerController := etcdcertsigner.NewEtcdCertSignerController(
 		coreClient,
 		operatorClient,
-		etcdClient,
 		kubeInformersForNamespaces,
 		configInformers.Config().V1().Infrastructures(),
 		controllerContext.EventRecorder,
@@ -192,6 +192,12 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		coreClient,
 		kubeInformersForNamespaces,
 	)
+	etcdEndpointsController := etcdendpointscontroller.NewEtcdEndpointsController(
+		operatorClient,
+		controllerContext.EventRecorder,
+		coreClient,
+		kubeInformersForNamespaces,
+	)
 
 	clusterMemberController := clustermembercontroller.NewClusterMemberController(
 		operatorClient,
@@ -233,7 +239,6 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 		controllerContext.EventRecorder,
 	)
 
-	operatorInformers.Start(ctx.Done())
 	operatorInformers.Start(ctx.Done())
 	kubeInformersForNamespaces.Start(ctx.Done())
 	configInformers.Start(ctx.Done())
@@ -241,20 +246,22 @@ func RunOperator(ctx context.Context, controllerContext *controllercmd.Controlle
 
 	go fsyncMetricController.Run(ctx, 1)
 	go staticResourceController.Run(ctx, 1)
-	go targetConfigReconciler.Run(1, ctx.Done())
-	go etcdCertSignerController.Run(1, ctx.Done())
+	go targetConfigReconciler.Run(ctx, 1)
+	go etcdCertSignerController.Run(ctx, 1)
 	go hostEtcdEndpointController2.Run(ctx, 1)
+	go etcdEndpointsController.Run(ctx, 1)
 	go resourceSyncController.Run(ctx, 1)
 	go statusController.Run(ctx, 1)
 	go configObserver.Run(ctx, 1)
-	go clusterMemberController.Run(ctx.Done())
-	go etcdMemberIPMigrator.Run(ctx.Done())
+	go clusterMemberController.Run(ctx, 1)
+	go etcdMemberIPMigrator.Run(ctx, 1)
 	go etcdMembersController.Run(ctx, 1)
-	go bootstrapTeardownController.Run(ctx.Done())
-	go staticPodControllers.Start(ctx)
-	go scriptController.Run(1, ctx.Done())
-	go envVarController.Run(1, ctx.Done())
+	go bootstrapTeardownController.Run(ctx, 1)
 	go unsupportedConfigOverridesController.Run(ctx, 1)
+	go scriptController.Run(ctx, 1)
+
+	go envVarController.Run(1, ctx.Done())
+	go staticPodControllers.Start(ctx)
 
 	<-ctx.Done()
 	return nil
@@ -270,7 +277,6 @@ var RevisionConfigMaps = []revision.RevisionResource{
 	{Name: "etcd-peer-client-ca"},
 	{Name: "etcd-metrics-proxy-serving-ca"},
 	{Name: "etcd-metrics-proxy-client-ca"},
-	{Name: "restore-etcd-pod"},
 }
 
 // RevisionSecrets is a list of secrets that are directly copied for the current values.  A different actor/controller modifies these.
@@ -281,6 +287,7 @@ var RevisionSecrets = []revision.RevisionResource{
 }
 
 var CertConfigMaps = []revision.RevisionResource{
+	{Name: "restore-etcd-pod"},
 	{Name: "etcd-scripts"},
 	{Name: "etcd-serving-ca"},
 	{Name: "etcd-peer-client-ca"},
